#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.16.0.0
visibility:           public
id:                   lsp-test-0.16.0.0-G75GRQ25LSvJ3vFvh3Mr5e
key:                  lsp-test-0.16.0.0-G75GRQ25LSvJ3vFvh3Mr5e
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  b449e2016eb24276f61d6a9c67d8296a
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m:Control.Applicative.Combinators,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-6fRnHC0piWmLNGya7ZKBXV:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-6fRnHC0piWmLNGya7ZKBXV:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-6fRnHC0piWmLNGya7ZKBXV:Language.LSP.Protocol.Types,
    Language.LSP.Test

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-test-0.16.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-test-0.16.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-test-0.16.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.16.0.0-G75GRQ25LSvJ3vFvh3Mr5e
depends:
    Diff-0.5-Am7LKUlc3753Bz8cDMWPBf Glob-0.10.2-E9Ofy58UjcEDtLkuI1NiLV
    aeson-2.2.1.0-FEnGzvKMunxDwDFhBeJYHO
    aeson-pretty-0.8.10-Ivax4iYwu8KFWXwjiRmlk4
    ansi-terminal-1.1-4Fc3pfbWuzJIdO3EFXFaIS
    async-2.2.6-9S5YBpAZQ2fGtiHAvRKHi7 base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-D87yZYcUfEep9NLn4SFvW
    conduit-1.3.6.1-7ztpQFzxkQu9fYslJzAtaH
    conduit-parse-0.2.1.1-8e9G8v0k69QATt0bCM25A containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    lens-5.3.4-B9QPRzrMZ8J355CXfNFvnN
    lens-aeson-1.2.3-BuOIc68lGpD152h2I1wgKQ
    lsp-2.2.0.0-81EvswuDs4iK20QcL1dFFp
    lsp-types-2.0.2.0-6fRnHC0piWmLNGya7ZKBXV mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m process-1.6.19.0
    row-types-1.0.1.2-8UtqxaozlYp4RcQR3tmfvC
    some-1.0.6-BJTtrISxM6b6MQEyx8mKPH text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

